summaryrefslogtreecommitdiffhomepage
path: root/mrbgems/mruby-math/test/math.rb
diff options
context:
space:
mode:
authorYukihiro "Matz" Matsumoto <[email protected]>2019-03-28 14:06:01 +0900
committerYukihiro "Matz" Matsumoto <[email protected]>2019-03-28 23:22:32 +0900
commit42f240796f653348ba0e0feefdec714b06cd3479 (patch)
tree746ea09130d7460024045b1b8ced57d0c7810c88 /mrbgems/mruby-math/test/math.rb
parent3b92b642eb3f7e3ed1b68bda86d073d310c5d131 (diff)
downloadmruby-42f240796f653348ba0e0feefdec714b06cd3479.tar.gz
mruby-42f240796f653348ba0e0feefdec714b06cd3479.zip
Use `Mrbtest::FLOAT_TOLERANCE` instead of `Math::TORELANCE`; ref #4345
Diffstat (limited to 'mrbgems/mruby-math/test/math.rb')
-rw-r--r--mrbgems/mruby-math/test/math.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/mrbgems/mruby-math/test/math.rb b/mrbgems/mruby-math/test/math.rb
index e9ea07cc1..4b474f212 100644
--- a/mrbgems/mruby-math/test/math.rb
+++ b/mrbgems/mruby-math/test/math.rb
@@ -3,9 +3,9 @@
##
# Performs fuzzy check for equality on methods returning floats
# on the basis of the Math::TOLERANCE constant.
def check_float(a, b)
- tolerance = Math::TOLERANCE
+ tolerance = Mrbtest::FLOAT_TOLERANCE
a = a.to_f
b = b.to_f
if a.finite? and b.finite?
@@ -3,9 +3,9 @@
##
# Performs fuzzy check for equality on methods returning floats
-# on the basis of the Math::TOLERANCE constant.
+# on the basis of the Mrbtest::FLOAT_TOLERANCE constant.
def check_float(a, b)